<?php
/**
 * Forest Nature: Customizer
 *
 * @subpackage Forest Nature
 * @since 1.0
 */

function forest_nature_customize_register( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_template_directory_uri() ). '/assets/css/customizer.css');

	// Add custom control.
  	require get_parent_theme_file_path( 'inc/customize/customize_toggle.php' );

	// Register the custom control type.
	$wp_customize->register_control_type( 'Forest_Nature_Toggle_Control' );

 	$wp_customize->add_section('forest_nature_pro', array(
        'title'    => __('UPGRADE FOREST NATURE PREMIUM', 'forest-nature'),
        'priority' => 1,
    ));
    $wp_customize->add_setting('forest_nature_pro', array(
        'default'           => null,
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control(new Forest_Nature_Pro_Control($wp_customize, 'forest_nature_pro', array(
        'label'    => __('Forest Nature PREMIUM', 'forest-nature'),
        'section'  => 'forest_nature_pro',
        'settings' => 'forest_nature_pro',
        'priority' => 1,
    )));

	// Theme General Settings
    $wp_customize->add_section('forest_nature_theme_settings',array(
        'title' => __('Theme General Settings', 'forest-nature'),
        'priority' => 1,
    ) );

    $wp_customize->add_setting( 'forest_nature_theme_loader', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'forest_nature_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Forest_Nature_Toggle_Control( $wp_customize, 'forest_nature_theme_loader', array(
		'label'       => esc_html__( 'Show Site Loader', 'forest-nature' ),
		'section'     => 'forest_nature_theme_settings',
		'type'        => 'toggle',
		'settings'    => 'forest_nature_theme_loader',
	) ) );

	$wp_customize->add_setting( 'forest_nature_scroll_enable', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'forest_nature_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Forest_Nature_Toggle_Control( $wp_customize, 'forest_nature_scroll_enable', array(
		'label'       => esc_html__( 'Show Scroll Top', 'forest-nature' ),
		'section'     => 'forest_nature_theme_settings',
		'type'        => 'toggle',
		'settings'    => 'forest_nature_scroll_enable',
	) ) );

	// Post Layouts
    $wp_customize->add_section('forest_nature_layout',array(
        'title' => __('Post Layout', 'forest-nature'),
        'description' => __( 'Change the post layout from below options', 'forest-nature' ),
        'priority' => 1
    ) );

	$wp_customize->add_setting( 'forest_nature_post_sidebar', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'forest_nature_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Forest_Nature_Toggle_Control( $wp_customize, 'forest_nature_post_sidebar', array(
		'label'       => esc_html__( 'Show Fullwidth', 'forest-nature' ),
		'section'     => 'forest_nature_layout',
		'type'        => 'toggle',
		'settings'    => 'forest_nature_post_sidebar',
	) ) );

	$wp_customize->add_setting( 'forest_nature_single_post_sidebar', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'forest_nature_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Forest_Nature_Toggle_Control( $wp_customize, 'forest_nature_single_post_sidebar', array(
		'label'       => esc_html__( 'Show Single Post Fullwidth', 'forest-nature' ),
		'section'     => 'forest_nature_layout',
		'type'        => 'toggle',
		'settings'    => 'forest_nature_single_post_sidebar',
	) ) );

    $wp_customize->add_setting('forest_nature_post_option',array(
		'default' => 'simple_post',
		'sanitize_callback' => 'forest_nature_sanitize_select'
	));
	$wp_customize->add_control('forest_nature_post_option',array(
		'label' => esc_html__('Select Layout','forest-nature'),
		'section' => 'forest_nature_layout',
		'setting' => 'forest_nature_post_option',
		'type' => 'radio',
        'choices' => array(
            'simple_post' => __('Simple Post','forest-nature'),
            'grid_post' => __('Grid Post','forest-nature'),
        ),
	));

    $wp_customize->add_setting('forest_nature_grid_column',array(
		'default' => '3_column',
		'sanitize_callback' => 'forest_nature_sanitize_select'
	));
	$wp_customize->add_control('forest_nature_grid_column',array(
		'label' => esc_html__('Grid Post Per Row','forest-nature'),
		'section' => 'forest_nature_layout',
		'setting' => 'forest_nature_grid_column',
		'type' => 'radio',
        'choices' => array(
            '1_column' => __('1','forest-nature'),
            '2_column' => __('2','forest-nature'),
            '3_column' => __('3','forest-nature'),
            '4_column' => __('4','forest-nature'),
            '5_column' => __('6','forest-nature'),
        ),
	));

	$wp_customize->add_setting( 'forest_nature_date', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'forest_nature_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Forest_Nature_Toggle_Control( $wp_customize, 'forest_nature_date', array(
		'label'       => esc_html__( 'Hide Date', 'forest-nature' ),
		'section'     => 'forest_nature_layout',
		'type'        => 'toggle',
		'settings'    => 'forest_nature_date',
	) ) );

	$wp_customize->add_setting( 'forest_nature_admin', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'forest_nature_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Forest_Nature_Toggle_Control( $wp_customize, 'forest_nature_admin', array(
		'label'       => esc_html__( 'Hide Author/Admin', 'forest-nature' ),
		'section'     => 'forest_nature_layout',
		'type'        => 'toggle',
		'settings'    => 'forest_nature_admin',
	) ) );

	$wp_customize->add_setting( 'forest_nature_comment', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'forest_nature_sanitize_checkbox',
	) );
	$wp_customize->add_control( new Forest_Nature_Toggle_Control( $wp_customize, 'forest_nature_comment', array(
		'label'       => esc_html__( 'Hide Comment', 'forest-nature' ),
		'section'     => 'forest_nature_layout',
		'type'        => 'toggle',
		'settings'    => 'forest_nature_comment',
	) ) );

	// Header
    $wp_customize->add_section('forest_nature_header',array(
        'title' => __('Header', 'forest-nature'),
        'description' => __( 'Add header information in the below feilds', 'forest-nature' ),
        'priority' => 3
    ) );

	$wp_customize->add_setting('forest_nature_call_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('forest_nature_call_text',array(
		'label' => esc_html__('Call Text','forest-nature'),
		'section' => 'forest_nature_header',
		'setting' => 'forest_nature_call_text',
		'type'    => 'text'
	));

	$wp_customize->add_setting('forest_nature_call_phone_number',array(
		'default' => '',
		'sanitize_callback' => 'forest_nature_sanitize_phone_number'
	));
	$wp_customize->add_control('forest_nature_call_phone_number',array(
		'label' => esc_html__('Phone Number','forest-nature'),
		'section' => 'forest_nature_header',
		'setting' => 'forest_nature_call_phone_number',
		'type'    => 'text'
	));

	$wp_customize->add_setting('forest_nature_mail_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('forest_nature_mail_text',array(
		'label' => esc_html__('Email Text','forest-nature'),
		'section' => 'forest_nature_header',
		'setting' => 'forest_nature_mail_text',
		'type'    => 'text'
	));

	$wp_customize->add_setting('forest_nature_mail_email_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_email'
	));
	$wp_customize->add_control('forest_nature_mail_email_address',array(
		'label' => esc_html__('Email Address','forest-nature'),
		'section' => 'forest_nature_header',
		'setting' => 'forest_nature_mail_email_address',
		'type'    => 'text'
	));

	$wp_customize->add_setting('forest_nature_location_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('forest_nature_location_text',array(
		'label' => esc_html__('Location Text','forest-nature'),
		'section' => 'forest_nature_header',
		'setting' => 'forest_nature_location_text',
		'type'    => 'text'
	));

	$wp_customize->add_setting('forest_nature_location_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('forest_nature_location_address',array(
		'label' => esc_html__('Location Adreess','forest-nature'),
		'section' => 'forest_nature_header',
		'setting' => 'forest_nature_location_address',
		'type'    => 'text'
	));

	$wp_customize->add_setting('forest_nature_timing_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('forest_nature_timing_text',array(
		'label' => esc_html__('Timing Text','forest-nature'),
		'section' => 'forest_nature_header',
		'setting' => 'forest_nature_timing_text',
		'type'    => 'text'
	));

	$wp_customize->add_setting('forest_nature_timing_open_time',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('forest_nature_timing_open_time',array(
		'label' => esc_html__('Opening Timing','forest-nature'),
		'section' => 'forest_nature_header',
		'setting' => 'forest_nature_timing_open_time',
		'type'    => 'text'
	));

    //Slider
	$wp_customize->add_section( 'forest_nature_slider_section' , array(
    	'title'      => __( 'Slider Settings', 'forest-nature' ),
    	'description' => __('Slider Image Dimension ( 1600px x 650px )','forest-nature'),
		'priority'   => 3,
	) );

	$wp_customize->add_setting('forest_nature_slide_heading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('forest_nature_slide_heading',array(
		'label' => esc_html__('Slider Text','forest-nature'),
		'section' => 'forest_nature_slider_section',
		'setting' => 'forest_nature_slide_heading',
		'type'    => 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post[]= 'select';
	foreach($categories as $category){
	if($i==0){
	  $default = $category->slug;
	  $i++;
	}
	$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('forest_nature_post_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'forest_nature_sanitize_select',
	));
	$wp_customize->add_control('forest_nature_post_setting',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => esc_html__('Select Category to display slider images','forest-nature'),
		'section' => 'forest_nature_slider_section',
	));

	// About Section
	$wp_customize->add_section( 'forest_nature_services_section' , array(
    	'title'      => __( 'About Us Section Settings', 'forest-nature' ),
		'priority'   => 4,
	) );

    $wp_customize->add_setting('forest_nature_services_heading',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('forest_nature_services_heading',array(
		'label'	=> esc_html__('Add Heading','forest-nature'),
		'section'	=> 'forest_nature_services_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('forest_nature_about_us_settigs',array(
		'sanitize_callback' => 'forest_nature_sanitize_dropdown_pages',
	));
	$wp_customize->add_control('forest_nature_about_us_settigs',array(
		'type'    => 'dropdown-pages',
		'label' => __('Select Page','forest-nature'),
		'section' => 'forest_nature_services_section',
	));

	//Footer
    $wp_customize->add_section( 'forest_nature_footer_copyright', array(
    	'title' => esc_html__( 'Footer Text', 'forest-nature' ),
    	'priority' => 6
	) );

    $wp_customize->add_setting('forest_nature_footer_text',array(
			'default'	=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
	));
		$wp_customize->add_control('forest_nature_footer_text',array(
			'label'	=> esc_html__('Copyright Text','forest-nature'),
			'section'	=> 'forest_nature_footer_copyright',
			'type'		=> 'text'
	));

	$wp_customize->add_setting('forest_nature_footer_widget',array(
		'default' => '4',
		'sanitize_callback' => 'forest_nature_sanitize_select'
	));
	$wp_customize->add_control('forest_nature_footer_widget',array(
		'label' => esc_html__('Footer Per Column','forest-nature'),
		'section' => 'forest_nature_footer_copyright',
		'setting' => 'forest_nature_footer_widget',
		'type' => 'radio',
		'choices' => array(
			'1'   => __('1 Column', 'forest-nature'),
			'2'  => __('2 Column', 'forest-nature'),
			'3' => __('3 Column', 'forest-nature'),
			'4' => __('4 Column', 'forest-nature')
		),
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'forest_nature_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'forest_nature_customize_partial_blogdescription',
	) );

	//front page
	$num_sections = apply_filters( 'forest_nature_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		$wp_customize->add_setting( 'panel_' . $i, array(
			'default'           => false,
			'sanitize_callback' => 'forest_nature_sanitize_dropdown_pages',
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'panel_' . $i, array(
			/* translators: %d is the front page section number */
			'label'          => sprintf( __( 'Front Page Section %d Content', 'forest-nature' ), $i ),
			'description'    => ( 1 !== $i ? '' : __( 'Select pages to feature in each area from the dropdowns. Add an image to a section by setting a featured image in the page editor. Empty sections will not be displayed.', 'forest-nature' ) ),
			'section'        => 'theme_options',
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'active_callback' => 'forest_nature_is_static_front_page',
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
			'selector'            => '#panel' . $i,
			'render_callback'     => 'forest_nature_front_page_section',
			'container_inclusive' => true,
		) );
	}
}
add_action( 'customize_register', 'forest_nature_customize_register' );

function forest_nature_customize_partial_blogname() {
	bloginfo( 'name' );
}
function forest_nature_customize_partial_blogdescription() {
	bloginfo( 'description' );
}
function forest_nature_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}
function forest_nature_is_view_with_layout_option() {
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}

define('FOREST_NATURE_PRO_LINK',__('https://www.ovationthemes.com/wordpress/nature-wordpress-theme/','forest-nature'));

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Forest_Nature_Pro_Control')):
    class Forest_Nature_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
	        <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( FOREST_NATURE_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE FOREST NATURE PREMIUM','forest-nature');?> </a>
	        </div>
            <div class="col-md">
                <img class="forest_nature_img_responsive " src="<?php echo esc_url(get_template_directory_uri()); ?>/screenshot.png">
            </div>
	        <div class="col-md">
	            <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('Forest Nature PREMIUM - Features', 'forest-nature'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'forest-nature');?> </li>
                    <li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'forest-nature');?> </li>
                   	<li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'forest-nature');?> </li>
                   	<li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'forest-nature');?> </li>
                   	<li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'forest-nature');?> </li>
                   	<li class="upsell-forest_nature"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'forest-nature');?> </li>
                </ul>
        	</div>
		    <div class="col-md upsell-btn upsell-btn-bottom">
	            <a href="<?php echo esc_url( FOREST_NATURE_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE FOREST NATURE PREMIUM','forest-nature');?> </a>
		    </div>
        </label>
    <?php } }
endif;
